==> openerp_6.1-20140804-233536-1.tar.gz: openerp-6.1-20140804-233536/openerp/addons/idea/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2010 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Ideas',
    'version': '0.1',
    'category': 'Tools',
    'complexity': "easy",
    'description': """
This module allows your user to easily and efficiently participate in enterprise innovation.
============================================================================================

It allows everybody to express ideas about different subjects.
Then, other users can comment on these ideas and vote for particular ideas.
Each idea has a score based on the different votes.
The managers can obtain an easy view of best ideas from all the users.
Once installed, check the menu 'Ideas' in the 'Tools' main menu.""",
    'author': 'OpenERP SA',
    'website': 'http://openerp.com',
    'depends': ['base_tools'],
    'init_xml': [],
    'update_xml': [
        'security/idea_security.xml',
        'security/ir.model.access.csv',
        'wizard/idea_post_vote_view.xml',
        'idea_view.xml',
        'idea_workflow.xml',
        'report/report_vote_view.xml',
    ],
    'demo_xml': [
        "idea_data.xml"
    ],
    'test':[
        'test/test_idea.yml'
    ],
    'installable': True,
    'certificate': '0071515601309',
    'images': ['images/1_ideas.jpeg','images/2_idea_categories.jpeg','images/3_vote_idea.jpeg'],
}
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> openerp-8.0dev-20140125-000101.tar.gz: openerp-8.0dev-20140125-000101/openerp/addons/idea/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-Today OpenERP S.A. (<http://openerp.com>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Ideas',
    'summary': 'Share and Discuss your Ideas',
    'version': '1.0',
    'category': 'Tools',
    'description': """
Share your ideas and participate in enterprise innovation
=========================================================

The Ideas module give users a way to express and discuss ideas, allowing everybody
to participate in enterprise innovation. Every user can suggest, comment ideas.
The managers can obtain an easy view of best ideas from all the users.
Once installed, check the menu 'Ideas' in the 'Tools' main menu.""",
    'author': 'OpenERP SA',
    'website': 'http://www.openerp.com',
    'depends': ['mail'],
    'data': [
        'security/idea.xml',
        'security/ir.model.access.csv',
        'views/idea.xml',
        'views/category.xml',
        'data/idea.xml',
        'data/idea_workflow.xml',
    ],
    'demo': [
        'demo/idea.xml',
    ],
    'installable': True,
    'application': True,
    'images': [],
    'css': [
        'static/src/css/idea_idea.css',
    ],
    'js': [],
    'qweb': [],
}

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
